<?php

// Icinga Web 2 X.509 Module | (c) 2019 Icinga GmbH | GPLv2

namespace Icinga\Module\X509\ProvidedHook;

use Icinga\Module\Director\Hook\ImportSourceHook;

abstract class X509ImportSource extends ImportSourceHook
{
}
